/* 
 * Copyright (C) 2009 EStrongs Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.estrongs.opentest;

import android.app.Activity;
import android.content.ActivityNotFoundException;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;
import android.widget.Toast;

public class TestFileManagerActivity extends Activity {
	
	protected static final int REQUEST_CODE_PICK_FILE_TO_OPEN = 1;
	protected static final int REQUEST_CODE_PICK_DIRECTORY = 2;
	
	protected EditText mEditText;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.test_file_manager);
        
        mEditText = (EditText) findViewById(R.id.etFilePath);
        
        findViewById(R.id.btnOpen).setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View arg0) {
				openFile();
			}
        });

        findViewById(R.id.btnPickDirectory).setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View arg0) {
				pickDirectory();
			}
        });
    }
    
   
    
    /**
     * This is called after the ES File Manager finished.
     */
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		
		if (resultCode != RESULT_OK || data == null) {
			return ;
		}
		
		Uri uri = data.getData();
		
		switch (requestCode) {
			case REQUEST_CODE_PICK_FILE_TO_OPEN:
				// obtain the filename
				if (uri != null) {
					mEditText.setText(uri.getPath());
					Toast.makeText(this, getString(R.string.open_message) + " " + uri.getPath(), 0).show();
				}				
				break;			
			case REQUEST_CODE_PICK_DIRECTORY:
				mEditText.setText(uri.getPath());
				Toast.makeText(this, getString(R.string.use_directory_message) + " " + uri.getPath(), 0).show();
				break;
		}
	}
	
	private void openFile(){
    	try{
    		Intent intent = new Intent("com.estrongs.action.PICK_FILE");
    		intent.putExtra("com.estrongs.intent.extra.TITLE", "Select File");
    		
    		startActivityForResult(intent, REQUEST_CODE_PICK_FILE_TO_OPEN);
	    } catch (ActivityNotFoundException e) {
			Toast.makeText(this, R.string.no_filemanager_installed, 0).show();
		}
    }
   
    private void pickDirectory(){
		
		Intent intent = new Intent("com.estrongs.action.PICK_DIRECTORY");
		intent.putExtra("com.estrongs.intent.extra.TITLE", "Select Directory");
		// Assign a path.
		intent.setData(Uri.parse("file://" + "/sdcard/ES File Explorer"));
		
		try {
			startActivityForResult(intent, REQUEST_CODE_PICK_DIRECTORY);
		} catch (ActivityNotFoundException e) {
			// No compatible file manager was found.
			Toast.makeText(this, getString(R.string.no_filemanager_installed),Toast.LENGTH_SHORT).show();
		}
    }    
}